from pyramid_debugtoolbar.panels import DebugPanel


_ = lambda x: x


class AjaxDebugPanel(DebugPanel):
    """
    Sample debug panel
    """
    name = 'Ajax'
    has_content = True
    template = 'pyramid_debugtoolbar_ajax.panels:templates/ajax.dbtmako'

    def __init__(self, request):
        self.data = data = {'request': request}

    @property
    def nav_title(self):
        return _(self.name)

    @property
    def title(self):
        return _(self.name)

    @property
    def url(self):
        return ''

    def render_content(self, request):
        self.data['toolbar_request'] = request
        return DebugPanel.render_content(self, request)



"""pyramid_debugtoolbar_ajax installation script.
"""
import os
import re
from setuptools import setup
from setuptools import find_packages

here = os.path.abspath(os.path.dirname(__file__))
README = open(os.path.join(here, "README.md")).read()
README = README.split("\n\n", 1)[0] + "\n"

# store version in the init.py
with open(os.path.join(os.path.dirname(__file__),
                       'pyramid_debugtoolbar_ajax',
                       '__init__.py'
                       )
          ) as v_file:
    VERSION = re.compile(
        r".*__VERSION__ = '(.*?)'",
        re.S).match(v_file.read()).group(1)


requires = ['pyramid_debugtoolbar>=2.2', ]

setup(
    name="pyramid_debugtoolbar_ajax",
    author="Jonathan Vanasco",
    author_email="jonathan@findmeon.com",
    url="https://github.com/jvanasco/pyramid_debugtoolbar_ajax",
    version=VERSION,
    description="Ajax support for pyramid_debugtoolbar",
    keywords="web pyramid",
    license="MIT",
    classifiers=[
        "Intended Audience :: Developers",
        "Framework :: Pyramid",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
    ],
    long_description=README,
    packages=find_packages(),
    include_package_data=True,
    zip_safe=False,
    install_requires=requires,
    test_suite="tests",
)
